==> pygame_ce-2.5.1.tar.gz: pygame_ce-2.5.1/src_c/doc/font_doc.h <==
/* Auto generated file: with make_docs.py .  Docs go in docs/reST/ref/ . */
#define DOC_FONT "pygame module for loading and rendering fonts"
#define DOC_FONT_INIT "init() -> None\ninitialize the font module"
#define DOC_FONT_QUIT "quit() -> None\nuninitialize the font module"
#define DOC_FONT_GETINIT "get_init() -> bool\ntrue if the font module is initialized"
#define DOC_FONT_GETDEFAULTFONT "get_default_font() -> string\nget the filename of the default font"
#define DOC_FONT_GETSDLTTFVERSION "get_sdl_ttf_version(linked=True) -> (major, minor, patch)\ngets SDL_ttf version"
#define DOC_FONT_GETFONTS "get_fonts() -> list of strings\nget all available fonts"
#define DOC_FONT_MATCHFONT "match_font(name, bold=False, italic=False) -> path\nfind a specific font on the system"
#define DOC_FONT_SYSFONT "SysFont(name, size, bold=False, italic=False) -> Font\ncreate a Font object from the system fonts"
#define DOC_FONT_FONT "Font(filename=None, size=20) -> Font\nFont(filename, size) -> Font\nFont(pathlib.Path, size) -> Font\nFont(object, size) -> Font\ncreate a new Font object from a file"
#define DOC_FONT_FONT_BOLD "bold -> bool\nGets or sets whether the font should be rendered in (faked) bold."
#define DOC_FONT_FONT_NAME "name -> str\nGets the font's name."
#define DOC_FONT_FONT_STYLENAME "style_name -> str\nGets the font's style_name."
#define DOC_FONT_FONT_ITALIC "italic -> bool\nGets or sets whether the font should be rendered in (faked) italics."
#define DOC_FONT_FONT_UNDERLINE "underline -> bool\nGets or sets whether the font should be rendered with an underline."
#define DOC_FONT_FONT_STRIKETHROUGH "strikethrough -> bool\nGets or sets whether the font should be rendered with a strikethrough."
#define DOC_FONT_FONT_ALIGN "align -> int\nSet how rendered text is aligned when given a wrap length."
#define DOC_FONT_FONT_POINTSIZE "point_size -> int\nGets or sets the font's point size"
#define DOC_FONT_FONT_RENDER "render(text, antialias, color, bgcolor=None, wraplength=0) -> Surface\ndraw text on a new Surface"
#define DOC_FONT_FONT_SIZE "size(text, /) -> (width, height)\ndetermine the amount of space needed to render text"
#define DOC_FONT_FONT_SETUNDERLINE "set_underline(bool, /) -> None\ncontrol if text is rendered with an underline"
#define DOC_FONT_FONT_GETUNDERLINE "get_underline() -> bool\ncheck if text will be rendered with an underline"
#define DOC_FONT_FONT_SETSTRIKETHROUGH "set_strikethrough(bool, /) -> None\ncontrol if text is rendered with a strikethrough"
#define DOC_FONT_FONT_GETSTRIKETHROUGH "get_strikethrough() -> bool\ncheck if text will be rendered with a strikethrough"
#define DOC_FONT_FONT_SETBOLD "set_bold(bool, /) -> None\nenable fake rendering of bold text"
#define DOC_FONT_FONT_GETBOLD "get_bold() -> bool\ncheck if text will be rendered bold"
#define DOC_FONT_FONT_SETITALIC "set_italic(bool, /) -> None\nenable fake rendering of italic text"
#define DOC_FONT_FONT_METRICS "metrics(text, /) -> list\ngets the metrics for each character in the passed string"
#define DOC_FONT_FONT_GETITALIC "get_italic() -> bool\ncheck if the text will be rendered italic"
#define DOC_FONT_FONT_GETLINESIZE "get_linesize() -> int\nget the line space of the font text"
#define DOC_FONT_FONT_GETHEIGHT "get_height() -> int\nget the height of the font"
#define DOC_FONT_FONT_SETPOINTSIZE "set_point_size(size, /) -> int\nset the point size of the font"
#define DOC_FONT_FONT_GETPOINTSIZE "get_point_size() -> int\nget the point size of the font"
#define DOC_FONT_FONT_GETASCENT "get_ascent() -> int\nget the ascent of the font"
#define DOC_FONT_FONT_GETDESCENT "get_descent() -> int\nget the descent of the font"
#define DOC_FONT_FONT_SETSCRIPT "set_script(str, /) -> None\nset the script code for text shaping"
#define DOC_FONT_FONT_SETDIRECTION "set_direction(direction) -> None\nset the script direction for text shaping"

==> pygame_ce-2.5.4.dev2.tar.gz: pygame_ce-2.5.4.dev2/src_c/doc/font_doc.h <==
/* Auto generated file: with make_docs.py .  Docs go in docs/reST/ref/ . */
#define DOC_FONT "pygame module for loading and rendering fonts"
#define DOC_FONT_INIT "init() -> None\ninitialize the font module"
#define DOC_FONT_QUIT "quit() -> None\nuninitialize the font module"
#define DOC_FONT_GETINIT "get_init() -> bool\ntrue if the font module is initialized"
#define DOC_FONT_GETDEFAULTFONT "get_default_font() -> string\nget the filename of the default font"
#define DOC_FONT_GETSDLTTFVERSION "get_sdl_ttf_version(linked=True) -> (major, minor, patch)\ngets SDL_ttf version"
#define DOC_FONT_GETFONTS "get_fonts() -> list of strings\nget all available fonts"
#define DOC_FONT_MATCHFONT "match_font(name, bold=False, italic=False) -> path\nfind a specific font on the system"
#define DOC_FONT_SYSFONT "SysFont(name, size, bold=False, italic=False) -> Font\ncreate a Font object from the system fonts"
#define DOC_FONT_FONT "Font(filename=None, size=20) -> Font\nFont(filename, size) -> Font\nFont(pathlib.Path, size) -> Font\nFont(object, size) -> Font\ncreate a new Font object from a file"
#define DOC_FONT_FONT_BOLD "bold -> bool\nGets or sets whether the font should be rendered in (faked) bold."
#define DOC_FONT_FONT_NAME "name -> str\nGets the font's name."
#define DOC_FONT_FONT_STYLENAME "style_name -> str\nGets the font's style_name."
#define DOC_FONT_FONT_ITALIC "italic -> bool\nGets or sets whether the font should be rendered in (faked) italics."
#define DOC_FONT_FONT_UNDERLINE "underline -> bool\nGets or sets whether the font should be rendered with an underline."
#define DOC_FONT_FONT_STRIKETHROUGH "strikethrough -> bool\nGets or sets whether the font should be rendered with a strikethrough."
#define DOC_FONT_FONT_ALIGN "align -> int\nSet how rendered text is aligned when given a wrap length."
#define DOC_FONT_FONT_POINTSIZE "point_size -> int\nGets or sets the font's point size"
#define DOC_FONT_FONT_RENDER "render(text, antialias, color, bgcolor=None, wraplength=0) -> Surface\ndraw text on a new Surface"
#define DOC_FONT_FONT_SIZE "size(text, /) -> (width, height)\ndetermine the amount of space needed to render text"
#define DOC_FONT_FONT_SETUNDERLINE "set_underline(bool, /) -> None\ncontrol if text is rendered with an underline"
#define DOC_FONT_FONT_GETUNDERLINE "get_underline() -> bool\ncheck if text will be rendered with an underline"
#define DOC_FONT_FONT_SETSTRIKETHROUGH "set_strikethrough(bool, /) -> None\ncontrol if text is rendered with a strikethrough"
#define DOC_FONT_FONT_GETSTRIKETHROUGH "get_strikethrough() -> bool\ncheck if text will be rendered with a strikethrough"
#define DOC_FONT_FONT_SETBOLD "set_bold(bool, /) -> None\nenable fake rendering of bold text"
#define DOC_FONT_FONT_GETBOLD "get_bold() -> bool\ncheck if text will be rendered bold"
#define DOC_FONT_FONT_SETITALIC "set_italic(bool, /) -> None\nenable fake rendering of italic text"
#define DOC_FONT_FONT_METRICS "metrics(text, /) -> list\ngets the metrics for each character in the passed string"
#define DOC_FONT_FONT_GETITALIC "get_italic() -> bool\ncheck if the text will be rendered italic"
#define DOC_FONT_FONT_GETLINESIZE "get_linesize() -> int\nget the line space of the font text"
#define DOC_FONT_FONT_SETLINESIZE "set_linesize(linesize) -> None\nset the line space of the font text"
#define DOC_FONT_FONT_GETHEIGHT "get_height() -> int\nget the height of the font"
#define DOC_FONT_FONT_SETPOINTSIZE "set_point_size(size, /) -> None\nset the point size of the font"
#define DOC_FONT_FONT_GETPOINTSIZE "get_point_size() -> int\nget the point size of the font"
#define DOC_FONT_FONT_GETASCENT "get_ascent() -> int\nget the ascent of the font"
#define DOC_FONT_FONT_GETDESCENT "get_descent() -> int\nget the descent of the font"
#define DOC_FONT_FONT_SETSCRIPT "set_script(str, /) -> None\nset the script code for text shaping"
#define DOC_FONT_FONT_SETDIRECTION "set_direction(direction) -> None\nset the script direction for text shaping"
